{% load i18n cms %}
<section class="contact">
  <div class="wrapper">
    <div class="title">
      <h1>{{section.title}}</h1>
    </div>

    <div class="form">
      <form method="post" class="cms">
        {% csrf_token %}
        {% for field in form %}
          {% include 'cms/formfield.html' with field=field %}
        {% endfor %}
        <button class="button" name="section" value="{{section.pk}}">{% trans 'Send' %}</button>
      </form>
    </div>
  </div>

  {% editsection '<img src="/static/cms/edit.png">' %}
</section>
