$font: Merriweather, sans-serif;

html, body {
  font-family: $font;
  line-height: 2;
  margin: 0;
  padding: 0;
}

div.edit {
  position: fixed;
  bottom: 1.1em;
  right: 1.1em;
  z-index: 1000;

  button {
    display: block;
    padding: 0;
    outline: none;
    background: none;
    border: none;

    img {
      width: 65px;
      height: auto;
    }
  }
}

/* Form elements */

form.cms {
  background: #bfb;
  overflow: hidden;
  min-height: 100vh;
  $background: #fff6;
  display: flex;
  align-items: center;
  justify-content: center;

  div.wrapper {
    max-width: none;
    flex: 1 1 800px;
    @media(min-width: 1000px) { flex: 0 1 800px }
    padding: 0 0.5em;
    padding-top: 0.25em;
  }

  fieldset {
    background: $background;
    border: 0.5px solid #ccc;
    clear: both;
    margin: 0.5em 0;
    margin-top: 0.25em;
    padding: 0.25em 0.5em;
    padding-top: 0;
    border-radius: 0.25em;
  }

  img {
    display: block;
    clear: both;
    width: 50px;
    cursor: pointer;
  }

  div.formfield {
    margin: 0.25em 0;
    overflow: hidden;
    clear: both;
    box-sizing: border-box;

    &.type, &.number, &.slug {
      width: 77%;
      clear: none;
      float: left;
      margin-top: 0;
    }
    &.number {
      width: 20%;
      float: right;
    }
    &.title {
      font-weight: 700;
    }

    &.error {
      border: 2px dotted red;
      border-radius: 3px;
      padding: 0.5em;
      margin-top: 0.5em;
      background: #f001;

      select, input, textarea {
        background: white;
      }
    }

    div.label, label {
      font-size: 0.7rem;
      font-weight: 400;
      text-align: left;
      margin-bottom: 2px;
    }

    div.input {
      overflow: hidden;
    }

    div.helptext {
      color: #666;
      font-size: 12px !important;
      font-weight: 400 !important;
    }
  }

  input, select, textarea {
    height: 32px;
    background: $background;
    color: black;
    border: 0.5px solid #ccc;
    border-radius: 3px;
    font-size: 1rem;
    display: block;
    width: 100%;
    box-sizing: border-box;
    margin: 0;
    padding: 5px 8px;
    font-family: inherit;
    font-weight: inherit;
  }
  input[type=checkbox] {
    width: auto;
    display: inline-block;
    vertical-align: middle;
  }
  textarea {
    line-height: 1.5;
    overflow-y: hidden;
  }
  select {
    padding-left: 3px;
  }

  ul.errorlist {
    margin: 0;
    margin-bottom: 1em;
    padding: 0;
    list-style: none;
    color: red;
    font-size: 12px;

    li {
      margin: 0;
      padding: 0;
    }
  }

  div.global_error {
    border: 2px dotted red;
    border-radius: 3px;
    padding: 10px;
    margin: 0.5em 0;
    background: #f001;
    color: red;
    font-weight: 700;

    ul.errorlist {
      margin: 0;
      font-size: inherit;
    }
  }

  .errors {
    color: red;
    font-weight: 700;
  }
}

@font-face {
  font-family: 'Merriweather';
  font-style: normal;
  font-weight: 300;
  src: url('Merriweather_300.woff2') format('woff2');
}

@font-face {
  font-family: 'Merriweather';
  font-style: normal;
  font-weight: 700;
  src: url('Merriweather_700.woff2') format('woff2');
}


